==> jc-1.4.0.tar.gz: soot/util/DeterministicHashMap.h <==
// public class soot.util.DeterministicHashMap

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class c3934e18893865c2 soot_util_DeterministicHashMap

// header file dependencies
// @dep_header java_util_HashMap

#include "java/util/HashMap.h"

#ifndef _JC_soot_util_DeterministicHashMap_H_
#define _JC_soot_util_DeterministicHashMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_util_DeterministicHashMap$sub_refs	_jc_soot_util_DeterministicHashMap$sub_refs;
typedef struct _jc_soot_util_DeterministicHashMap$sub_nonrefs	_jc_soot_util_DeterministicHashMap$sub_nonrefs;
typedef struct _jc_soot_util_DeterministicHashMap$refs	_jc_soot_util_DeterministicHashMap$refs;
typedef struct _jc_soot_util_DeterministicHashMap$nonrefs	_jc_soot_util_DeterministicHashMap$nonrefs;
typedef struct _jc_soot_util_DeterministicHashMap$object	_jc_soot_util_DeterministicHashMap$object;

typedef const struct _jc_soot_util_DeterministicHashMap$vmethods	_jc_soot_util_DeterministicHashMap$vmethods;
typedef const struct _jc_soot_util_DeterministicHashMap$vtable	_jc_soot_util_DeterministicHashMap$vtable;
typedef const struct _jc_soot_util_DeterministicHashMap$vtype	_jc_soot_util_DeterministicHashMap$vtype;

// Constructors
extern void _jc_soot_util_DeterministicHashMap$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, jint);
extern void _jc_soot_util_DeterministicHashMap$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, jint, jfloat);

// Virtual methods
extern struct _jc_object *_jc_soot_util_DeterministicHashMap$method$entries$d8e4daf9891fd963(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *);
extern struct _jc_object *_jc_soot_util_DeterministicHashMap$method$keySet$de7ce456e8d4e55b(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_DeterministicHashMap$method$put$3bd1c078a0faa8da(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_DeterministicHashMap$method$remove$9efb7487051fd088(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$entries$d8e4daf9891fd963;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$keySet$de7ce456e8d4e55b;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$put$3bd1c078a0faa8da;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$remove$9efb7487051fd088;

// Virtual methods structure
struct _jc_soot_util_DeterministicHashMap$vmethods {
	struct _jc_object	*(*entries$d8e4daf9891fd963)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *);
	struct _jc_object	*(*keySet$de7ce456e8d4e55b)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *);
	struct _jc_java_lang_Object$object	*(*put$3bd1c078a0faa8da)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*remove$9efb7487051fd088)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_util_DeterministicHashMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_soot_util_DeterministicHashMap$vmethods	soot_util_DeterministicHashMap;
};

// Vtype
struct _jc_soot_util_DeterministicHashMap$vtype {
	_jc_type			type;
	_jc_soot_util_DeterministicHashMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_DeterministicHashMap$sub_refs {
	struct _jc_object	*keys;
};

// Reference instance fields (object)
struct _jc_soot_util_DeterministicHashMap$refs {
    _jc_soot_util_DeterministicHashMap$sub_refs	soot_util_DeterministicHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_DeterministicHashMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_DeterministicHashMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_soot_util_DeterministicHashMap$sub_nonrefs	soot_util_DeterministicHashMap;
};

// Object instance structure
struct _jc_soot_util_DeterministicHashMap$object {
	_jc_soot_util_DeterministicHashMap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_DeterministicHashMap$vtype	*vtype;
	_jc_soot_util_DeterministicHashMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_DeterministicHashMap$vtype _jc_soot_util_DeterministicHashMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_DeterministicHashMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_DeterministicHashMap$class_object;

#endif	/* _JC_soot_util_DeterministicHashMap_H_ */

==> jc-1.4.6.tar.gz: soot/util/DeterministicHashMap.h <==
// public class soot.util.DeterministicHashMap

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class c3934e18893865c2 soot_util_DeterministicHashMap

// header file dependencies
// @dep_header java_util_HashMap

#include "java/util/HashMap.h"

#ifndef _JC_soot_util_DeterministicHashMap_H_
#define _JC_soot_util_DeterministicHashMap_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_soot_util_DeterministicHashMap$sub_refs	_jc_soot_util_DeterministicHashMap$sub_refs;
typedef struct _jc_soot_util_DeterministicHashMap$sub_nonrefs	_jc_soot_util_DeterministicHashMap$sub_nonrefs;
typedef struct _jc_soot_util_DeterministicHashMap$refs	_jc_soot_util_DeterministicHashMap$refs;
typedef struct _jc_soot_util_DeterministicHashMap$nonrefs	_jc_soot_util_DeterministicHashMap$nonrefs;
typedef struct _jc_soot_util_DeterministicHashMap$object	_jc_soot_util_DeterministicHashMap$object;

typedef const struct _jc_soot_util_DeterministicHashMap$vmethods	_jc_soot_util_DeterministicHashMap$vmethods;
typedef const struct _jc_soot_util_DeterministicHashMap$vtable	_jc_soot_util_DeterministicHashMap$vtable;
typedef const struct _jc_soot_util_DeterministicHashMap$vtype	_jc_soot_util_DeterministicHashMap$vtype;

// Constructors
extern void _jc_soot_util_DeterministicHashMap$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_util_DeterministicHashMap$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, jint, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_util_DeterministicHashMap$method$entries$d8e4daf9891fd963(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_util_DeterministicHashMap$method$keySet$de7ce456e8d4e55b(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_DeterministicHashMap$method$put$3bd1c078a0faa8da(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_DeterministicHashMap$method$remove$9efb7487051fd088(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$entries$d8e4daf9891fd963;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$keySet$de7ce456e8d4e55b;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$put$3bd1c078a0faa8da;
extern _jc_method _jc_soot_util_DeterministicHashMap$method_info$remove$9efb7487051fd088;

// Virtual methods structure
struct _jc_soot_util_DeterministicHashMap$vmethods {
	struct _jc_object	*(*entries$d8e4daf9891fd963)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*keySet$de7ce456e8d4e55b)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*put$3bd1c078a0faa8da)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*remove$9efb7487051fd088)(_jc_env *, struct _jc_soot_util_DeterministicHashMap$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_DeterministicHashMap$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_soot_util_DeterministicHashMap$vmethods	soot_util_DeterministicHashMap;
};

// Vtype
struct _jc_soot_util_DeterministicHashMap$vtype {
	_jc_type			type;
	_jc_soot_util_DeterministicHashMap$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_DeterministicHashMap$sub_refs {
	struct _jc_object	*keys;
};

// Reference instance fields (object)
struct _jc_soot_util_DeterministicHashMap$refs {
    _jc_soot_util_DeterministicHashMap$sub_refs	soot_util_DeterministicHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_DeterministicHashMap$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_DeterministicHashMap$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_soot_util_DeterministicHashMap$sub_nonrefs	soot_util_DeterministicHashMap;
};

// Object instance structure
struct _jc_soot_util_DeterministicHashMap$object {
	_jc_soot_util_DeterministicHashMap$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_DeterministicHashMap$vtype	*vtype;
	_jc_soot_util_DeterministicHashMap$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_DeterministicHashMap$vtype _jc_soot_util_DeterministicHashMap$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_DeterministicHashMap, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_DeterministicHashMap$class_object;

#endif	/* _JC_soot_util_DeterministicHashMap_H_ */
